#!env python
# -*- coding: iso-8859-1 -*-
###########################################################################
#
# File:            sourceFroniusSolarAPI.py
#
# License:         Donationware, see attached LICENSE file for more
#                  information
#
# Author:          Olli Lammi (olammi@iki.fi)
#
# Version:         1.8a
#
# Date:            31.08.2023
#
# Description:     TaloLogger configuration wrapper for Fronius library.
#
# Version history: ** 31.08.2023 v1.8a (Olli Lammi) **
#                  Initial version.
#
###########################################################################

# Imports

from modules.core import configuration
from modules.core import dataSource

import froniusSolarAPI


###########################################################################

# Classes

class FroniusSolarAPIConf(froniusSolarAPI.FroniusSolarAPI, configuration.Configurable, dataSource.DataSource):
    def __init__(self, modname):
        configuration.Configurable.__init__(self)
        self.setModuleName(modname)
        froniusSolarAPI.FroniusSolarAPI.__init__(self)
        dataSource.DataSource.__init__(self)
        self.setID(modname)

    def getServiceName(self):
        return self.getModuleName()

    def runDataSourceQueryCommandImpl(self, cmds):
        return self.runQueryCommand(cmds)

    def handleConfiguration(self, conf):
        self.hostname = conf.getValue('HOSTNAME', '', self.getModuleName())
        self.port = int(conf.getValue('PORT', '80', self.getModuleName()))
        return (1, '')

    def initConfiguration(self):
        if len(self.hostname) <= 0:
            return (-1, 'Missing Fronius Solar API hostname.')

        if not self.initAPI():
            return (0, 'Error initializing Fronius API.')

        return (1, '')

    @staticmethod
    def getModuleTypeName():
        return 'FRONIUS'

    @staticmethod
    def getAllowedConfigurationKeys():
        return (['HOSTNAME', 'PORT'], [])
