#!env python
# -*- coding: iso-8859-1 -*-
###########################################################################
# 
# File:            sourceHusdata.py
#
# License:         Donationware, see attached LICENSE file for more 
#                  information
#
# Author:          Olli Lammi (olammi@iki.fi)
#
# Version:         1.7l
#
# Date:            22.4.2020
#
# Description:     TaloLogger configuration wrapper for HusdataSerial library.
#                  
# Version history: ** 31.5.2016 v1.7h (Olli Lammi) **
#                  First version. 
#
#                  ** 22.04.2020 v1.7l (Olli Lammi) **
#                  Added optional XH-mode to Husdata data source module.
#
###########################################################################

# Imports

from modules.core import configuration
from modules.core import dataSource

import husdataSerial


###########################################################################

# Classes

class HusdataConf(husdataSerial.HusdataSerial, configuration.Configurable, dataSource.DataSource):
    def __init__(self, modname):
        configuration.Configurable.__init__(self)
        self.setModuleName(modname)
        husdataSerial.HusdataSerial.__init__(self, None)
        dataSource.DataSource.__init__(self)
        self.setID(modname)
        self.xhmode = False
        self.port = ''

    def getServiceName(self):
        return self.getModuleName()

    def runDataSourceQueryCommandImpl(self, cmds):
        return self.runDataSourceQueryMultiWrapper(cmds)
    
    def handleConfiguration(self, conf):
        self.port = conf.getValue('SERIAL_PORT', '', self.getModuleName())
        self.xhmode = conf.isTrue('XH_MODE', self.getModuleName())
        return (1, '')
        
    def initConfiguration(self):
        if len(self.port) <= 0:
            return (-1, 'Missing Husdata interface serial port path.')

        self.setPort(self.port)
        self.setXHmode(self.xhmode)

        if not self.startModule():
            return (0, 'Error accessing Husdata interface.')
        else:
            self.Log('Started Husdata serial module using device version: ' + self.getDeviceVersion())
        return (1, '')

    def releaseConfiguration(self):
        self.terminate()
        if not self.hasTerminated():
            self.wait_sleeping()
        return (1, '')

    @staticmethod
    def getModuleTypeName():
        return 'HUSDATA'

    @staticmethod
    def getAllowedConfigurationKeys():
        return (['SERIAL_PORT', 'XH_MODE'], [])

