#!env python
# -*- coding: iso-8859-1 -*-
###########################################################################
# 
# File:            sourceOumanSerial.py
#
# License:         Donationware, see attached LICENSE file for more 
#                  information
#
# Author:          Olli Lammi (olammi@iki.fi)
#
# Version:         1.4i
#
# Date:            13.02.2012
#
# Description:     TaloLogger configuration wrapper for OumanSerial library.
#                  
# Version history: ** 11.10.2011 v1.4e (Olli Lammi) **
#                  Moved from main taloLogger application module. 
#
#                  ** 13.02.2012 v1.4i (Olli Lammi) **
#                  Multisupport.
#
###########################################################################

# Imports

from modules.core import configuration
from modules.core import dataSource

import oumanSerial


###########################################################################

# Classes

class OumanSerialConf(oumanSerial.OumanSerial, configuration.Configurable, dataSource.DataSource):
    def __init__(self, modname):
        configuration.Configurable.__init__(self)
        self.setModuleName(modname)
        oumanSerial.OumanSerial.__init__(self, None, None)
        dataSource.DataSource.__init__(self)
        self.setID(modname)

    def getServiceName(self):
        return self.getModuleName()

    def runDataSourceQueryCommandImpl(self, cmds):
        return self.runDataSourceQueryMultiWrapper(cmds)

    def handleConfiguration(self, conf):
        self.port = conf.getValue('SERIAL_PORT', '', self.getModuleName())
        self.device = conf.getValue('DEVICE', '', self.getModuleName())
        return (1, '')
        
    def initConfiguration(self):
        if len(self.port) <= 0:
            return (-1, 'Missing Ouman serial port path.')
        if len(self.device) <= 0:
            return (-1, 'Missing Ouman device name.')
        
        self.setPort(self.port)
        self.setDevice(self.device)
        
        temps = oumanSerial.getOumanDataPart(self.runQueryId(1))
        if len(temps) <= 0:
            return (0, 'Error reading device id from Ouman controller.')
        else:
            if len(temps) > 6:
                temps = temps[6:]
            self.Log('Received Ouman device ID: ' + temps)
        return (1, '')

    @staticmethod
    def getModuleTypeName():
        return 'OUMAN'

    @staticmethod
    def getAllowedConfigurationKeys():
        return (['DEVICE', 'SERIAL_PORT'], [])

