#!env python
# -*- coding: iso-8859-1 -*-
###########################################################################
# 
# File:            sourceTelldus.py
#
# License:         Donationware, see attached LICENSE file for more 
#                  information
#
# Author:          Olli Lammi (olammi@iki.fi)
#
# Version:         1.6b
#
# Date:            22.01.2015
#
# Description:     TaloLogger configuration wrapper for TelldusCore source.
#                  
# Version history: ** 12.05.2014 v1.6a (Olli Lammi) **
#                  Added to taloLogger. 
#
#                  ** 22.01.2015 v1.6b (Olli Lammi) **
#                  Added support for Telldus Live API service. 
#
###########################################################################

# Imports

import string

from modules.core import configuration
from modules.core import dataSource

import telldusCore


###########################################################################

# Classes

class TelldusConf(telldusCore.TelldusSource, configuration.Configurable, dataSource.DataSource):
    def __init__(self, modname):
        configuration.Configurable.__init__(self)
        self.setModuleName(modname)
        telldusCore.TelldusSource.__init__(self)
        dataSource.DataSource.__init__(self)
        self.setID(modname)
        
        self.libType = 'LIB'
        self.publicKey = None
        self.privateKey = None
        self.authToken = None
        self.authTokenSecret = None
        
    def getServiceName(self):
        return self.getModuleName()

    def handleConfiguration(self, conf):
        self.libType = string.upper(conf.getValue('TYPE', 'LIB', self.getModuleName()))
        if not self.libType in ['LIB', 'LIVE']: 
            return (-1, "Unknown Telldus library type.")
        
        self.setLibraryType(self.libType)
        
        if self.libType == 'LIVE':
            self.publicKey = conf.getValue('PUBLIC_KEY', '', self.getModuleName())
            self.privateKey = conf.getValue('PRIVATE_KEY', '', self.getModuleName())
            self.authToken = conf.getValue('TOKEN', '', self.getModuleName())
            self.authTokenSecret = conf.getValue('TOKEN_SECRET', '', self.getModuleName())
        
            if len(self.publicKey) <= 0:
                return (-1, 'Telldus Live API: Missing public key.')
            if len(self.privateKey) <= 0:
                return (-1, 'Telldus Live API: Missing private key.')
            if len(self.authToken) <= 0:
                return (-1, 'Telldus Live API: Missing token.')
            if len(self.authTokenSecret) <= 0:
                return (-1, 'Telldus Live API: Missing token secret.')
            
            self.setLiveAuth(self.publicKey, self.privateKey, self.authToken, self.authTokenSecret)
        
        self.setDatapoints(self.handleTelldusConf(conf)) 
        return (1, '')

    def handleTelldusConf(self, conf):
        pointmap = {}
        for item in conf.getValue('SENSOR', [], self.getModuleName()):
            temps = string.split(item, ':', 5)
            if len(temps) < 5:
                self.log("ERROR: Invalid SENSOR configuration: " + item)
            else:
                try:
                    key = string.strip(temps[0])
                    protocol = string.strip(temps[1])
                    model = string.strip(temps[2])
                    id = int(string.strip(temps[3]))
                    datatype = string.upper(string.strip(temps[4]))
                except:
                    key = ''
                if len(key) <= 0:
                    self.log("ERROR: Invalid SENSOR configuration: " + item)
                else:
                    pointmap[key] = [protocol, model, id, datatype]
        return pointmap
            
    def initConfiguration(self):
        if len(self.DATAPOINTS.keys()) <= 0:
            return (0, 'No data points configured for TELLDUS datasource module.')

        if not self.initLibrary():     
            if self.libType == 'LIB':   
                return (0, 'Unable to load libtelldus-core.so.2 library.')
            elif self.libType == 'LIVE':
                return (0, 'Unable to connect or authenticate to Telldus Live service.')
        
        return (1, '')

    def releaseConfiguration(self):
        self.closeLibrary()
        return (1, '')

    def runDataSourceQueryCommandImpl(self, cmds):
        return self.runQueryCommand(cmds)

    @staticmethod
    def getModuleTypeName():
        return 'TELLDUS'

    @staticmethod
    def getAllowedConfigurationKeys():
        return (['TYPE', 'PUBLIC_KEY', 'PRIVATE_KEY', 'TOKEN', 'TOKEN_SECRET'], ['SENSOR'])
