#!env python
# -*- coding: iso-8859-1 -*-
###########################################################################
# 
# File:            sourceThermIQSerial.py
#
# License:         Donationware, see attached LICENSE file for more 
#                  information
#
# Author:          Olli Lammi (olammi@iki.fi)
#
# Version:         1.4i
#
# Date:            13.02.2012
#
# Description:     TaloLogger configuration wrapper for ThermIQSerial library.
#                  
# Version history: ** 18.10.2011 v1.4e (Olli Lammi) **
#                  First version for testing. 
#
#                  ** 13.02.2012 v1.4i (Olli Lammi) **
#                  Multisupport
#
###########################################################################

# Imports

from modules.core import configuration
from modules.core import dataSource

import thermIQSerial


###########################################################################

# Classes

class ThermIQSerialConf(thermIQSerial.ThermIQSerial, configuration.Configurable, dataSource.DataSource):
    def __init__(self, modname):
        configuration.Configurable.__init__(self)
        self.setModuleName(modname)
        thermIQSerial.ThermIQSerial.__init__(self, None, None)
        dataSource.DataSource.__init__(self)
        self.setID(modname)

    def getServiceName(self):
        return self.getModuleName()

    def runDataSourceQueryCommandImpl(self, cmds):
        return self.runDataSourceQueryMultiWrapper(cmds)

    def handleConfiguration(self, conf):
        self.port = conf.getValue('SERIAL_PORT', '', self.getModuleName())
        self.device = conf.getValue('DEVICE', '', self.getModuleName())
        return (1, '')
        
    def initConfiguration(self):
        if len(self.port) <= 0:
            return (-1, 'Missing ThermIQ serial port path.')
        if len(self.device) <= 0:
            return (-1, 'Missing ThermIQ device name.')

        self.setPort(self.port)
        self.setDevice(self.device)

        temps = self.getVersion()
        if len(temps) <= 0:
            return (0, 'Error reading version from ThermIQ controller.')
        else:
            self.Log('Received ThermIQ device version: ' + temps)
        return (1, '')

    @staticmethod
    def getModuleTypeName():
        return 'THERMIQ'

    @staticmethod
    def getAllowedConfigurationKeys():
        return (['DEVICE', 'SERIAL_PORT'], [])
